==> borb-2.0.8.tar.gz: borb-2.0.8/tests/pdf/canvas/layout/chunk_of_text/test_write_paragraph_with_accented_letters.py <==
import typing
import unittest
from datetime import datetime
from pathlib import Path

from borb.io.read.types import Decimal
from borb.pdf.canvas.layout.page_layout.multi_column_layout import SingleColumnLayout
from borb.pdf.canvas.layout.table.fixed_column_width_table import (
    FixedColumnWidthTable as Table,
)
from borb.pdf.canvas.layout.text.paragraph import Paragraph
from borb.pdf.document import Document
from borb.pdf.page.page import Page
from borb.pdf.pdf import PDF
from borb.toolkit.text.simple_text_extraction import SimpleTextExtraction


class TestWriteAccentedLetters(unittest.TestCase):
    """
    This test creates a PDF with a Paragraph in it, containing various accented characters.
    """

    def __init__(self, methodName="runTest"):
        super().__init__(methodName)
        # find output dir
        p: Path = Path(__file__).parent
        while "output" not in [x.stem for x in p.iterdir() if x.is_dir()]:
            p = p.parent
        p = p / "output"
        self.output_dir = Path(p, Path(__file__).stem.replace(".py", ""))
        if not self.output_dir.exists():
            self.output_dir.mkdir()

    def test_write_document(self):

        # create document
        pdf = Document()

        # add page
        page = Page()
        pdf.append_page(page)

        # set layout
        layout = SingleColumnLayout(page)

        # add test information
        layout.add(
            Table(number_of_columns=2, number_of_rows=3)
            .add(Paragraph("Date", font="Helvetica-Bold"))
            .add(Paragraph(datetime.now().strftime("%d/%m/%Y, %H:%M:%S")))
            .add(Paragraph("Test", font="Helvetica-Bold"))
            .add(Paragraph(Path(__file__).stem))
            .add(Paragraph("Description", font="Helvetica-Bold"))
            .add(
                Paragraph(
                    "This test was the result of an issue logged by a user. "
                    "The user noticed several characters were not written correctly. "
                    "This bug impacted only words with accented characters."
                )
            )
            .set_padding_on_all_cells(Decimal(2), Decimal(2), Decimal(2), Decimal(2))
        )

        accented_words: typing.List[str] = [
            "Nombre",
            "Dirección",
            "Código Postal",
            "Número de Factura",
        ]
        for w in accented_words:
            layout.add(Paragraph(w, font="Helvetica-bold"))

        # determine output location
        out_file = self.output_dir / "output.pdf"

        # attempt to store PDF
        with open(out_file, "wb") as in_file_handle:
            PDF.dumps(in_file_handle, pdf)

        # attempt to re-open PDF
        l = SimpleTextExtraction()
        with open(out_file, "rb") as in_file_handle:
            PDF.loads(in_file_handle, [l])

        # verify that the words are in the extracted text
        s: str = l.get_text_for_page(0)
        for w in accented_words:
            assert w in s, "Missing word %s in extracted text" % w

==> borb-2.0.13.tar.gz: borb-2.0.13/tests/pdf/canvas/layout/chunk_of_text/test_write_paragraph_with_accented_letters.py <==
import typing
import unittest
from datetime import datetime
from pathlib import Path

from borb.io.read.types import Decimal
from borb.pdf.canvas.layout.page_layout.multi_column_layout import SingleColumnLayout
from borb.pdf.canvas.layout.table.fixed_column_width_table import (
    FixedColumnWidthTable as Table,
)
from borb.pdf.canvas.layout.text.paragraph import Paragraph
from borb.pdf.document import Document
from borb.pdf.page.page import Page
from borb.pdf.pdf import PDF
from borb.toolkit.text.simple_text_extraction import SimpleTextExtraction


class TestWriteParagraphWithAccentedLetters(unittest.TestCase):
    """
    This test creates a PDF with a Paragraph in it, containing various accented characters.
    """

    def __init__(self, methodName="runTest"):
        super().__init__(methodName)
        # find output dir
        p: Path = Path(__file__).parent
        while "output" not in [x.stem for x in p.iterdir() if x.is_dir()]:
            p = p.parent
        p = p / "output"
        self.output_dir = Path(p, Path(__file__).stem.replace(".py", ""))
        if not self.output_dir.exists():
            self.output_dir.mkdir()

    def test_write_document(self):

        # create document
        pdf = Document()

        # add page
        page = Page()
        pdf.append_page(page)

        # set layout
        layout = SingleColumnLayout(page)

        # add test information
        layout.add(
            Table(number_of_columns=2, number_of_rows=3)
            .add(Paragraph("Date", font="Helvetica-Bold"))
            .add(Paragraph(datetime.now().strftime("%d/%m/%Y, %H:%M:%S")))
            .add(Paragraph("Test", font="Helvetica-Bold"))
            .add(Paragraph(Path(__file__).stem))
            .add(Paragraph("Description", font="Helvetica-Bold"))
            .add(
                Paragraph(
                    "This test was the result of an issue logged by a user. "
                    "The user noticed several characters were not written correctly. "
                    "This bug impacted only words with accented characters."
                )
            )
            .set_padding_on_all_cells(Decimal(2), Decimal(2), Decimal(2), Decimal(2))
        )

        accented_words: typing.List[str] = [
            "Nombre",
            "Dirección",
            "Código Postal",
            "Número de Factura",
        ]
        for w in accented_words:
            layout.add(Paragraph(w, font="Helvetica-bold"))

        # determine output location
        out_file = self.output_dir / "output.pdf"

        # attempt to store PDF
        with open(out_file, "wb") as in_file_handle:
            PDF.dumps(in_file_handle, pdf)

        # attempt to re-open PDF
        l = SimpleTextExtraction()
        with open(out_file, "rb") as in_file_handle:
            PDF.loads(in_file_handle, [l])

        # verify that the words are in the extracted text
        s: str = l.get_text_for_page(0)
        for w in accented_words:
            assert w in s, "Missing word %s in extracted text" % w
